@@ -125,7 +125,10 @@ class Manager(object):
             if(erase_if_exists):
                 print(index_name + " deleted and recreated")
                 self.connect.indices.delete(index=index_name)
-        self.connect.indices.create(index=index_name,body=settings,ignore=400)
+        try:
+            self.connect.indices.create(index=index_name,body=settings,ignore=400)
+        except Exception as e:
+            print(e)
         
         
     def save_to_index(self, generator):
